@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub engine {
     my $class = shift;
@@ -43,7 +43,7 @@ Search::OpenSearch - provide search results in OpenSearch format
  );
  my $response = $engine->search(
     q   => 'quick brown fox',   # query
-    s   => 'rank desc',         # sort order
+    s   => 'score desc',        # sort order
     o   => 0,                   # offset
     p   => 25,                  # page size
     h   => 1,                   # highlight query terms in results
