@@ -6,7 +6,7 @@ use base qw( Rose::ObjectX::CAF );
 
 __PACKAGE__->mk_accessors(qw( names sample_size ));
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 1;
 
@@ -30,7 +30,7 @@ Search::OpenSearch::Facets - represents Facet metadata
  );
  my $response = $engine->search(
     q           => 'quick brown fox',   # query
-    s           => 'rank desc',         # sort order
+    s           => 'score desc',        # sort order
     o           => 0,                   # offset
     p           => 25,                  # page size
     h           => 1,                   # highlight query terms in results
