@@ -31,7 +31,7 @@ my @attributes = qw(
 );
 __PACKAGE__->mk_accessors( @attributes, qw( debug pps error ) );
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 our %ATTRIBUTES = ();
 
@@ -118,7 +118,7 @@ Search::OpenSearch::Response - provide search results in OpenSearch format
  );
  my $response = $engine->search(
     q           => 'quick brown fox',   # query
-    s           => 'rank desc',         # sort order
+    s           => 'score desc',        # sort order
     o           => 0,                   # offset
     p           => 25,                  # page size
     h           => 1,                   # highlight query terms in results
