@@ -10,7 +10,7 @@ use URI::Encode qw( uri_encode );
 use POSIX qw( strftime );
 use Data::UUID;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 my $XMLer = Search::Tools::XML->new;
 
@@ -226,7 +226,7 @@ Search::OpenSearch::Response::XML - provide search results in XML format
  );
  my $response = $engine->search(
     q           => 'quick brown fox',   # query
-    s           => 'rank desc',         # sort order
+    s           => 'score desc',        # sort order
     o           => 0,                   # offset
     p           => 25,                  # page size
     h           => 1,                   # highlight query terms in results
